/*
TAR.PRG

written by:

Bruce E. Hansen
Department of Economics
Boston College
Chestnut Hill, MA 02167
(617) 552-3678
bruce.hansen@bc.edu
http:/fmwww.bc.edu/EC-V/Hansen.fac.html


This is a GAUSS program file.  It estimates a TAR model for
U.S. umemployment. It calls the GAUSS procedure THR_EST.PRC.
See this file for further documentation.

*/

_graph=1;
#include thr_est.prc;

let omit = 0;                @ lags omitted from autoregression,
                               if all included set omit=0       @
h = 1;                       @ set h=1 for heteroskedasticity-correction
                               else set h=0                     @
name = "UR";                 @ name of series                   @
trim_per = .15;              @ percentage of sample to trim from ends
                               for test, e.g., trim_per=.15     @
p = 12;                      @ autoregressive order             @


@ Load Data into vector y @
load u[]=lhmu.db;
load c[]=lhmc.db;
t1 = floor(u[1]);
ts = 1959;
s1 = (ts-t1)*12+3;
n  = rows(u);
y = (u[s1:n]./c[s1:n])*100;
n = rows(y);

graphset;
fonts("complex simgrma");
xt = seqa(ts+1/12,1/12,n);
_pdate="";
xlabel("Unemployment Rate, Men 20+ Years");
xtics(1955,2000,5,5);
xy(xt,y);

@  Taking First Differences @

dy = y[2:n] - y[1:n-1];

output file = tar.out reset;
"Sample Period " ts~xt[n];"";

@ Create data matrix (lags, etc) @

rd = 1000;
n = rows(dy);
dat = dy[1+p:n];
names = name;
j=1; do while j<=p;
  if sumc(omit .== j)==0;
    dat=dat~dy[1+p-j:n-j];
    if j<10;
      pn = ftocv(j,1,0);
    else;
      pn = ftocv(j,2,0);
    endif;
    namej = "" $+ "DY(t-" $+ pn $+ ")";
    names = names|namej;
  endif;
j=j+1;endo;
xi = seqa(2,1,cols(dat)-1);
d = 12;
q = y[p+1:n] - y[p+1-d:n-d];
dat = dat~q;
if d<10;
  pn = ftocv(d,1,0);
else;
  pn = ftocv(d,2,0);
endif;
namej = "" $+ "Y*(t-" $+ pn $+ ")";
names = names|namej;

qi = cols(dat);
graphset;
{qhat,sse} = thr_est(dat,names,1,xi,qi,1);

output off;


/******************************************************/

@ Spectral Density Analysis  @

let ar1[12,1] =
       -0.18598887
        0.084300567
        0.13224909
        0.16545326
        0.069956299
        0.026875568
        0.061981325
        0.044455321
       -0.031329244
       -0.057287164
        0.090689689
       -0.13584895;
sig1 =    0.024656225 ;

let ar2[12,1]=
       0.24120656
       0.24083988
       0.12358546
      -0.026373618
      -0.019790247
      -0.084133292
      -0.15050268
      -0.034745770
       0.092079241
       0.10290617
      -0.11438944
      -0.41237342  ;
sig2 =   0.038820986;

c1 = (-rev(ar1))|1;
c2 = (-rev(ar2))|1;

n = 500;
omegas = seqa(0,pi/n,n);
sp1 = zeros(n,1);
sp2 = zeros(n,1);

omegai = 1; do while omegai<=n;

  omega = omegas[omegai];
  eo1 = exp(omega*sqrt(-1));
  eo2 = exp(-omega*sqrt(-1));

  sp1[omegai] = (sig1/(2*pi))
  /(polyeval(eo1,c1)
   *polyeval(eo2,c1));

  sp2[omegai] = (sig2/(2*pi))
  /(polyeval(eo1,c2)
   *polyeval(eo2,c2));

omegai=omegai+1;endo;

graphset;
_pdate="";
fonts("complex simgrma");
xlabel("Spectral Density by Regime");
_plwidth = 4;
let _pltype = 6 4;
_plegstr="Regime 1\000Regime 2";
let _plegctl[1,4] = 1 5 2.4 .03;
ytics(0,.04,.01,1);
xy(omegas,sp1~sp2);



/***************************************************/

@  Classification of Regimes  @

q1 = .212918;
q2 = .339885;
i1 = (q.<q1);
i2 = (q.<=q2) - i1;
i3 = 1 - i1 - i2;
yp = y[p+2:rows(y)];

d1 = yp.*i1 - (1-i1);
d2 = yp.*i2 - (1-i2);
d3 = yp.*i3 - (1-i3);
d = d1~d2~d3;

n = rows(d);
graphset;
_plctrl = -1;
_psymsiz = 3;
let _pstype = 3 8 4;
fonts("complex simgrma");
xt = seqa(ts+1+2/12,1/12,n);
_pdate="";
ylabel("Unemployment Rate");
xlabel("Classification by Regime");
_plegstr="Regime 1\000Uncertain\000Regime 2";
_plegctl= 1;
ytics(2,10,1,2);
xtics(1968,1998,5,5);
st = 12*10;
xy(xt[st:n],d[st:n,.]);

