/*
TEST.PRG

written by:

Bruce E. Hansen
Department of Economics
Boston College
Chestnut Hill, MA 02167
(617) 552-3678
bruce.hansen@bc.edu
http:/fmwww.bc.edu/EC-V/Hansen.fac.html


This is a GAUSS program file.  It tests for threshold effects
in autoregressive models.
It calls the GAUSS procedures THR_EST.PRC, THR_TEST.PRC, and
THR_HET.PRC.  See these files for further documentation.

*/

_graph=0;
#include thr_est.prc;
#include thr_test.prc;
#include thr_het.prc;

let omit = 0;                @ lags omitted from autoregression,
                               if all included set omit=0       @
h = 1;                       @ set h=1 for heteroskedasticity-correction
                               else set h=0                     @
name = "UR";                 @ name of series                   @
trim_per = .15;              @ percentage of sample to trim from ends
                               for test, e.g., trim_per=.15     @
rep = 1000;                  @ number of bootstrap replications @
p = 12;                      @ autoregressive order             @


@ Load Data into vector y @
load u[]=lhmu.db;
load c[]=lhmc.db;
t1 = floor(u[1]);
ts = 1959;
s1 = (ts-t1)*12+3;
n  = rows(u);
y = (u[s1:n]./c[s1:n])*100;
n = rows(y);

@  Taking First Differences @

y = y[2:n] - y[1:n-1];

output file = test.out reset;
"Sample Period " ts~xt[n];"";

@ Create data matrix (lags, etc) @

rd = 1000;
n = rows(y);
dat = y[1+p:n];
names = name;
j=1; do while j<=p;
  if sumc(omit .== j)==0;
    dat=dat~y[1+p-j:n-j];
    if j<10;
      pn = ftocv(j,1,0);
    else;
      pn = ftocv(j,2,0);
    endif;
    namej = "" $+ "Y(t-" $+ pn $+ ")";
    names = names|namej;
  endif;
j=j+1;endo;
xi = seqa(2,1,cols(dat)-1);
ya = y[p:n-1];
j=2; do while j<=12;
  ya = ya + y[1+p-j:n-j];
  yj = ya;
  yj = round(yj*rd)/rd;
  dat=dat~yj;
    if j<10;
      pn = ftocv(j,1,0);
    else;
      pn = ftocv(j,2,0);
    endif;
    namej = "" $+ "Y*(t-" $+ pn $+ ")";
    names = names|namej;
j=j+1;endo;

"Tests for Threshold in SETAR Model";
"";
"          d          Qhat        SSE         F-test        P-value ";
"";
format 12,6;

d = 1; do while d<=12;
qi = 1+d;
{qhat,sse} = thr_est(dat,names,1,xi,qi,1);
if h==0;
  {f_test,p_value} = thr_test(dat,1,xi,qi,trim_per,rep);
elseif h==1;
  {f_test,p_value} = thr_het(dat,1,xi,qi,trim_per,rep);
endif;
dstat = qhat~sse~f_test~p_value;
d~dstat;
d=d+1;endo;

"";"";"";

"Tests for Threshold in Long-Difference Model";
"";
"          d          Qhat        SSE         F-test        P-value ";
"";
d = 2; do while d<=12;
qi = p+d;
{qhat,sse} = thr_est(dat,names,1,xi,qi,1);
if h==0;
  {f_test,p_value} = thr_test(dat,1,xi,qi,trim_per,rep);
elseif h==1;
  {f_test,p_value} = thr_het(dat,1,xi,qi,trim_per,rep);
endif;
dstat = qhat~sse~f_test~p_value;
d~dstat;
d=d+1;endo;

output off;



